@@ -16,4 +16,6 @@ class AccountingYear(EconomicSerializer, QueryMixin):
         return False
 
     def get_account_entries(self):
-        return AccountEntry.filter(self.auth, year=self.year)
\ No newline at end of file
+        # self.entries is the URL for this AccountingYear's entries
+        # we have to remove the query parameters from the URL first, since they are added again by _query
+        return AccountEntry._query(self.auth, self.entries.split('?')[0], page_size=1000)
